==> haskell-crypto-pubkey-types-0.4.3-435.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-FJtMwIK4cJXEyUUz4Hc1UZ
key:                  crypto-pubkey-types-0.4.3-FJtMwIK4cJXEyUUz4Hc1UZ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  05f517fafc186a86a89ef82ebe732343
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-FJtMwIK4cJXEyUUz4Hc1UZ
depends:
    asn1-encoding-0.9.6-f2brNU34Hf3xe9CSPQRHn
    asn1-types-0.3.4-463kziEGjPc1qXS6uMhRJO base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-436-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-LtvOSYtrBsuKcyGAqwMgm8
key:                  crypto-pubkey-types-0.4.3-LtvOSYtrBsuKcyGAqwMgm8
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  0ad91b9ca8d9ff9621e6bf0f0bdef31c
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-LtvOSYtrBsuKcyGAqwMgm8
depends:
    asn1-encoding-0.9.6-4rkJHO0pUeFCGFdsLyrUdt
    asn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
